@@ -3,7 +3,7 @@ package Finance::CoinbasePro::API::CLI::Fill
 
 use strict;
 use warnings;
-our $VERSION = '0.016';
+our $VERSION = '0.017';
 
 use Mouse;
 use Finance::CoinbasePro::API::CLI::Util::CurrencyUtil qw(format_currency);
@@ -135,11 +135,13 @@ user_id => "513378df5210ff660900002b",
 
 
 
+
+
 #################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################
 
 =head1 NAME
 
-Finance::CoinbasePro::API::CLI::Fill - this knows about Finance::GDAX::Fill objects and can display them
+lib::::Finance::CoinbasePro::API::CLI::Fill - lib::::Finance::CoinbasePro::API::CLI::Fill
 
 
 =head1 DESCRIPTION
@@ -151,8 +153,6 @@ returns a string like '2018-06-13 11:14:11: buy BTC-USD: 10.00000000 BTC at $7,0
 
 L<Finance::CoinbasePro::API::CLI::Value> 
 
-L<Finance::CoinbasePro::API::CLI::Util::DateUtil> 
-
 L<Finance::CoinbasePro::API::CLI::Util::CurrencyUtil> 
 
 L<Mouse> 
