@@ -3,7 +3,7 @@ package Finance::CoinbasePro::API::CLI::Util::CurrencyUtil
 
 use strict;
 use warnings;
-our $VERSION = '0.016';
+our $VERSION = '0.017';
 
 use base qw(Exporter);
 our @EXPORT_OK = qw( get_product_currencies
@@ -147,11 +147,13 @@ sub _log10 { my $n = shift; return 2 unless $n; return log($n) / log(10); }
 
 1;
 
+
+
 #################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################
 
 =head1 NAME
 
-Finance::CoinbasePro::API::CLI::Util::CurrencyUtil - formats values in currencies for display
+lib::::Finance::CoinbasePro::API::CLI::Util::CurrencyUtil - lib::::Finance::CoinbasePro::API::CLI::Util::CurrencyUtil
 
 
 =head1 DESCRIPTION
